@@ -1,5 +1,5 @@
 import base64
-import datetime
+# import datetime
 import hashlib
 import hmac
 import json
@@ -12,6 +12,7 @@ from typing import Dict, List
 from uuid import uuid4
 
 import requests
+from pydantic import ValidationError
 
 from instagrapi import config
 from instagrapi.exceptions import (
@@ -22,7 +23,7 @@ from instagrapi.exceptions import (
     TwoFactorRequired,
 )
 from instagrapi.utils import dumps, gen_token, generate_jazoest
-from instagrapi.zones import CET
+# from instagrapi.zones import CET
 
 
 class PreLoginFlowMixin:
@@ -39,11 +40,11 @@ class PreLoginFlowMixin:
         bool
             A boolean value
         """
-        self.set_contact_point_prefill("prefill")
-        self.get_prefill_candidates(True)
+        # self.set_contact_point_prefill("prefill")
+        # self.get_prefill_candidates(True)
         self.set_contact_point_prefill("prefill")
         self.sync_launcher(True)
-        self.sync_device_features(True)
+        # self.sync_device_features(True)
         return True
 
     def get_prefill_candidates(self, login: bool = False) -> Dict:
@@ -61,17 +62,15 @@ class PreLoginFlowMixin:
             A boolean value
         """
         data = {
-            "android_device_id": self.device_id,
+            "android_device_id": self.android_device_id,
             "client_contact_points": "[{\"type\":\"omnistring\",\"value\":\"%s\",\"source\":\"last_login_attempt\"}]" % self.username,
             "phone_id": self.phone_id,
             "usages": '["account_recovery_omnibox"]',
-            "device_id": self.device_id,
+            "device_id": self.uuid,
         }
         # if login is False:
         data["_csrftoken"] = self.token
-        return self.private_request(
-            "accounts/get_prefill_candidates/", data, login=login
-        )
+        return self.private_request("accounts/get_prefill_candidates/", data, login=login)
 
     def sync_device_features(self, login: bool = False) -> Dict:
         """
@@ -90,7 +89,7 @@ class PreLoginFlowMixin:
         data = {
             "id": self.uuid,
             "server_config_retrieval": "1",
-            "experiments": config.LOGIN_EXPERIMENTS,
+            # "experiments": config.LOGIN_EXPERIMENTS,
         }
         if login is False:
             data["_uuid"] = self.uuid
@@ -137,7 +136,11 @@ class PreLoginFlowMixin:
         Dict
             A dictionary of response from the call
         """
-        data = {"phone_id": self.phone_id, "usage": usage, "_csrftoken": self.token}
+        data = {
+            "phone_id": self.phone_id,
+            "usage": usage,
+            # "_csrftoken": self.token
+        }
         return self.private_request("accounts/contact_point_prefill/", data, login=True)
 
 
@@ -156,16 +159,13 @@ class PostLoginFlowMixin:
             A boolean value
         """
         check_flow = []
-        chance = random.randint(1, 100) % 2 == 0
-        check_flow.append(self.get_timeline_feed([chance and "is_pull_to_refresh"]))
-        check_flow.append(
-            self.get_reels_tray_feed(
-                reason="pull_to_refresh" if chance else "cold_start"
-            )
-        )
+        # chance = random.randint(1, 100) % 2 == 0
+        # reason = "pull_to_refresh" if chance else "cold_start"
+        check_flow.append(self.get_reels_tray_feed("cold_start"))
+        check_flow.append(self.get_timeline_feed(["cold_start_fetch"]))
         return all(check_flow)
 
-    def get_timeline_feed(self, options: List[Dict] = []) -> Dict:
+    def get_timeline_feed(self, options: List[Dict] = ["pull_to_refresh"]) -> Dict:
         """
         Get your timeline feed
 
@@ -186,33 +186,29 @@ class PostLoginFlowMixin:
             "X-CM-Latency": str(random.randint(1, 5)),
         }
         data = {
-            "feed_view_info": "",
+            "feed_view_info": "[]",  # e.g. [{"media_id":"2634223601739446191_7450075998","version":24,"media_pct":1.0,"time_info":{"10":63124,"25":63124,"50":63124,"75":63124},"latest_timestamp":1628253523186}]
             "phone_id": self.phone_id,
             "battery_level": random.randint(25, 100),
-            "timezone_offset": datetime.datetime.now(CET()).strftime("%z"),
+            "timezone_offset": str(self.timezone_offset),
             "_csrftoken": self.token,
             "device_id": self.uuid,
-            "request_id": self.device_id,
+            "request_id": self.request_id,
             "_uuid": self.uuid,
             "is_charging": random.randint(0, 1),
             "will_sound_on": random.randint(0, 1),
             "session_id": self.client_session_id,
-            "bloks_versioning_id": "e538d4591f238824118bfcb9528c8d005f2ea3becd947a3973c030ac971bb88e",
+            "bloks_versioning_id": "fd16828964e43a367fe1e9a42740151f6d917073c27ca07ccfe0e359c3c82482",
         }
-
-        if "is_pull_to_refresh" in options:
+        if "pull_to_refresh" in options:
             data["reason"] = "pull_to_refresh"
             data["is_pull_to_refresh"] = "1"
-        elif "is_pull_to_refresh" not in options:
+        elif "cold_start_fetch" in options:
             data["reason"] = "cold_start_fetch"
             data["is_pull_to_refresh"] = "0"
-
-        if "push_disabled" in options:
-            data["push_disabled"] = "true"
-
-        if "recovered_from_crash" in options:
-            data["recovered_from_crash"] = "1"
-
+        # if "push_disabled" in options:
+        #     data["push_disabled"] = "true"
+        # if "recovered_from_crash" in options:
+        #     data["recovered_from_crash"] = "1"
         return self.private_request(
             "feed/timeline/", json.dumps(data), with_signature=False, headers=headers
         )
@@ -234,7 +230,12 @@ class PostLoginFlowMixin:
         data = {
             "supported_capabilities_new": config.SUPPORTED_CAPABILITIES,
             "reason": reason,
-            "_csrftoken": self.token,
+            "timezone_offset": str(self.timezone_offset),
+            "tray_session_id": self.tray_session_id,
+            "request_id": self.request_id,
+            "latest_preloaded_reel_ids": "[]",  # [{"reel_id":"6009504750","media_count":"15","timestamp":1628253494,"media_ids":"[\"2634301737009283814\",\"2634301789371018685\",\"2634301853921370532\",\"2634301920174570551\",\"2634301973895112725\",\"2634302037581608844\",\"2634302088273817272\",\"2634302822117736694\",\"2634303181452199341\",\"2634303245482345741\",\"2634303317473473894\",\"2634303382971517344\",\"2634303441062726263\",\"2634303502039423893\",\"2634303754729475501\"]"},{"reel_id":"4357392188","media_count":"4","timestamp":1628250613,"media_ids":"[\"2634142331579781054\",\"2634142839803515356\",\"2634150786575125861\",\"2634279566740346641\"]"},{"reel_id":"5931631205","media_count":"7","timestamp":1628253023,"media_ids":"[\"2633699694927154768\",\"2634153361241413763\",\"2634196788830183839\",\"2634219197377323622\",\"2634294221109889541\",\"2634299705648894876\",\"2634299760434939842\"]"}],
+            "page_size": 50,
+            # "_csrftoken": self.token,
             "_uuid": self.uuid,
         }
         return self.private_request("feed/reels_tray/", data)
@@ -249,9 +250,12 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
     relogin_attempt = 0
     device_settings = {}
     client_session_id = ""
+    tray_session_id = ""
     advertising_id = ""
-    device_id = ""
+    android_device_id = ""
+    request_id = ""
     phone_id = ""
+    app_id = "567067343352427"
     uuid = ""
     mid = ""
     country = "US"
@@ -313,7 +317,7 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
 
         try:
             user = self.user_info_v1(int(user_id))
-        except PrivateError:
+        except (PrivateError, ValidationError):
             user = self.user_short_gql(int(user_id))
         self.username = user.username
         self.cookie_dict["ds_user_id"] = user.pk
@@ -369,7 +373,7 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
             "username": username,
             "adid": self.advertising_id,
             "guid": self.uuid,
-            "device_id": self.device_id,
+            "device_id": self.uuid,
             "google_tokens": "[]",
             "login_attempt_count": "0"
         }
@@ -392,7 +396,7 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
                 "username": username,
                 "trust_this_device": "0",
                 "guid": self.uuid,
-                "device_id": self.device_id,
+                "device_id": self.uuid,
                 "waterfall_id": str(uuid4()),
                 "verification_method": "3"
             }
@@ -424,7 +428,7 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
             "user_id": user_id,
             "adid": self.advertising_id,
             "guid": self.uuid,
-            "device_id": self.device_id,
+            "device_id": self.uuid,
             "login_nonce": nonce,
             "_csrftoken": self.token
         }
@@ -497,7 +501,10 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
                 "uuid": self.uuid,
                 "client_session_id": self.client_session_id,
                 "advertising_id": self.advertising_id,
-                "device_id": self.device_id,
+                "android_device_id": self.android_device_id,
+                # "device_id": self.uuid,
+                "request_id": self.request_id,
+                "tray_session_id": self.tray_session_id,
             },
             "authorization_data": self.authorization_data,
             "cookies": requests.utils.dict_from_cookiejar(self.private.cookies),
@@ -628,7 +635,10 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
         self.uuid = uuids.get("uuid", self.generate_uuid())
         self.client_session_id = uuids.get("client_session_id", self.generate_uuid())
         self.advertising_id = uuids.get("advertising_id", self.generate_uuid())
-        self.device_id = uuids.get("device_id", self.generate_device_id())
+        self.android_device_id = uuids.get("android_device_id", self.generate_android_device_id())
+        self.request_id = uuids.get("request_id", self.generate_uuid())
+        self.tray_session_id = uuids.get("tray_session_id", self.generate_uuid())
+        # self.device_id = uuids.get("device_id", self.generate_uuid())
         return True
 
     def generate_uuid(self, prefix: str = '', suffix: str = '') -> str:
@@ -642,18 +652,16 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
         """
         return f'{prefix}{uuid.uuid4()}{suffix}'
 
-    def generate_device_id(self) -> str:
+    def generate_android_device_id(self) -> str:
         """
-        Helper to generate Device ID
+        Helper to generate Android Device ID
 
         Returns
         -------
         str
             A random android device id
         """
-        return (
-            "android-%s" % hashlib.md5(str(time.time()).encode()).hexdigest()[:16]
-        )
+        return "android-%s" % hashlib.md5(str(time.time()).encode()).hexdigest()[:16]
 
     def expose(self) -> Dict:
         """
@@ -681,7 +689,7 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
                 "_uuid": self.uuid,
                 "_uid": str(self.user_id),
                 "_csrftoken": self.token,
-                "device_id": self.device_id,
+                "device_id": self.uuid,
             },
             **data,
         )
