@@ -76,6 +76,23 @@ class CollectionMixin:
 
         return self.collection_medias(self.collection_pk_by_name(name))
 
+    def liked_medias(self, amount: int = 21, last_media_pk: int = 0) -> List[Media]:
+        """
+        Get media you have liked
+
+        Parameters
+        ----------
+        amount: int, optional
+            Maximum number of media to return, default is 21
+        last_media_pk: int, optional
+            Last PK user has seen, function will return medias after this pk. Default is 0
+        Returns
+        -------
+        List[Media]
+            A list of objects of Media
+        """
+        return self.collection_medias("liked", amount, last_media_pk)
+
     def collection_medias(
         self, collection_pk: str, amount: int = 21, last_media_pk: int = 0
     ) -> List[Media]:
@@ -98,6 +115,8 @@ class CollectionMixin:
         """
         if collection_pk.isdigit():
             private_request_endpoint = f"feed/collection/{collection_pk}/"
+        elif collection_pk.lower() == "liked":
+            private_request_endpoint = "feed/liked/"
         else:
             private_request_endpoint = "feed/saved/posts/"
 
@@ -118,7 +137,7 @@ class CollectionMixin:
             for item in result["items"]:
                 if last_media_pk and last_media_pk == item["media"]["pk"]:
                     return total_items
-                total_items.append(extract_media_v1(item["media"]))
+                total_items.append(extract_media_v1(item.get("media", item)))
             if not result.get("more_available"):
                 return total_items
             next_max_id = result.get("next_max_id", "")
